/*
 *  options.h - header definitions for all things related to program options
 *
 *	Project 1
 *	CSE 326, Winter 2008
 *	University of Washington
 *
 *  Created by Ilya Maykov on 1/6/05.
 *  Copyright 2005 University of Washington. All rights reserved.
 *
 */

#ifndef _OPTIONS_H_INCLUDED_
#define _OPTIONS_H_INCLUDED_

#include "types.h"

/*
 *	A structure to hold information about program options.
 */
typedef struct Options {
	SortType	sortType;	// the sort type passed from the command line
	SortOrder	sortOrder;	// the sort order for the initial input
	int			arraySize;	// the data set size
} Options;

/*
 *	This function takes the arguments passed to main (argc and argv) and a pointer
 *	to an Options structure. It then parses the program arguments and fills in the 
 *	options structure appropriately. Any omitted parameters are initialized to
 *	invalid values.
 *	Arguments:
 *		argc	-	arguments count passed to main
 *		argv	-	arguments vector passed to main
 *		pOpts	-	pointer to an Options structure to be filled in
 *	Returns:
 *		0 on success, non-0 on failure
 */
extern int
ParseOptions(int argc, const char **argv, Options *pOpts);


/*
 *	Prints a readable description of the contents of an Options structure to an output
 *	stream.
 *	Arguments:
 *		pOpts	-	pointer to an Options structure to be described
 *		stream - the output stream to use (usually stdout)
 *	Returns:
 *		0 on success, non-0 on failure
 */
extern int
PrintOptions(const Options *pOpts, FILE *stream);


/*
 *	Prints the program usage to an output stream.
 *	Arguments:
 *		stream	-	the output stream to use (usually stdout)
 *	Returns:
 *		0 on success, non-0 on failure
 */
extern int
PrintUsage(FILE *stream);

#endif //_OPTIONS_H_INCLUDED_
