/*
 *  sort.h	- header definitions for all things related to sorting
 *
 *	Project 1
 *	CSE 326, Winter 2008
 *	University of Washington
 *
 *  Created by Ilya Maykov on 1/6/05.
 *  Modified by Gyanit Singh.
 *  Copyright 2005 University of Washington. All rights reserved.
 *
 */
 
#ifndef _SORT_H_INCLUDED_
#define _SORT_H_INCLUDED_

#include "types.h"

/*
 *	Sort an array of integers using bubble sort. This is provided as an
 *	example only, and should not be used in any of your experiments.
 *	Arguments:
 *		array	-	the array to sort
 *		size	-	the size of the input array
 *	Returns:
 *		0 on success, non-0 on failure
 */
extern int
BubbleSort(int *array, int size);

/*
 *	Sort an array of integers using insertion sort.
 *	Arguments:
 *		array	-	the array to sort
 *		size	-	the size of the input array
 *	Returns:
 *		0 on success, non-0 on failure
 */
extern int
InsertionSort(int *array, int size);

/*
 *	Sort an array of integers using quick sort.
 *	When the size of a subarray reaches the value
 *	CUTOFF, use insertion sort to sort this subarray.
 *	Arguments:
 *		array	-	the array to sort
 *		size	-	the size of the input array
 *	Returns:
 *		0 on success, non-0 on failure
 */
extern int
QuickSortOne(int *array, int size);

/*
 *	Sort an array of integers using quick sort.
 *	When the size of a subarray reaches the value
 *	CUTOFF, just return.  Then, at the very end, make
 *	one call to insertion sort to sort the entire array.
 *	Arguments:
 *		array	-	the array to sort
 *		size	-	the size of the input array
 *	Returns:
 *		0 on success, non-0 on failure
 */
extern int
QuickSortTwo(int *array, int size);

/*
 *	Sort an array of integers using iterative merge sort.
 *	Arguments:
 *		array	-	the array to sort
 *		size	-	the size of the input array
 *	Returns:
 *		0 on success, non-0 on failure
 */
extern int
IterativeMergeSort(int *array, int size);

/*
 *	Sort an array of integers using recursive merge sort.
 *	Arguments:
 *		array	-	the array to sort
 *		size	-	the size of the input array
 *	Returns:
 *		0 on success, non-0 on failure
 */
extern int
RecursiveMergeSort(int *array, int size);

/*
 *	Verifies the sort order of an array.
 *	Arguments:
 *		array	-	the array to verify
 *		size	-	the size of the array
 *		sortOrder -	the sort order to verify. Must be one of
 *			{ kIncreasingOrder, kDecreasingOrder, kFlatOrder }
 *	Returns:
 *		0 on success, non-0 on failure
 */
extern int
VerifySortOrder(int *array, int size, SortOrder sortOrder);



#endif //_SORT_H_INCLUDED_
