/*
 *  utils.h - header definitions for miscellaneous utility functions
 *
 *	Project 1
 *	CSE 326, Winter 2008
 *	University of Washington
 *
 *  Created by Ilya Maykov on 1/6/05.
 *  Copyright 2005 University of Washington. All rights reserved.
 *
 */

#ifndef _UTILS_H_INCLUDED_
#define _UTILS_H_INCLUDED_

#include "types.h"

/*
 *	Returns the current time, in milliseconds since Jan 1st, 1970.
 *	Arguments:
 *		none
 *	Returns:
 *		the number of milliseconds since Jan 1st, 1970
 */
extern int
CurrentTime(void);


/*
 *	Create an array of integers ordered according to a particular sort order. This function
 *	allocates memory. The caller is responsible for freeing this memory, which can be
 *	done with the SafeFree() macro defined below.
 *	Arguments:
 *		size	-	the requested size of the array
 *		order	-	a sort order for the initial elements
 *	Returns:
 *		a pointer to the beginning of the new array on success, NULL on failure
 */
extern int*
CreateArray(int size, SortOrder order);


/*
 *	This macro frees memory allocated by any of the malloc() family of functions.
 */
#ifndef SafeFree
#define SafeFree(x) if((x)) { free((x)); (x) = NULL; }
#endif


/*
 *	Print the contents of an integer array to an output stream.
 *	Arguments:
 *		array	-	the array to display
 *		size	-	size of the array
 *		stream	-	output stream to which the array contents will be printed (usually stdout)
 *	Returns:
 *		0 on success, non-0 on failure
 */
extern int 
PrintArray(const int *array, int size, FILE *stream);

#endif	//_UTILS_H_INCLUDED_
